@@ -22,8 +22,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef _ATSPI_PRIVATE_H_
-#define _ATSPI_PRIVATE_H_
+#pragma once
 
 #include "atspi-device-listener-private.h"
 #include "atspi-event-listener-private.h"
@@ -39,5 +38,3 @@
 G_BEGIN_DECLS
 void _atspi_reregister_device_listeners ();
 G_END_DECLS
-
-#endif /* _ATSPI_PRIVATE_H_ */
